import { InboundResponseType, OutboundResponseType } from './message-transformer';
/**
 * Manages pending inbound and outbound requests. Ensures that requests and
 * responses interact correctly and obey the Embedded Protocol.
 */
export declare class RequestTracker {
    private readonly requests;
    /** The next available request ID. */
    get nextId(): number;
    /**
     * Adds an entry for a pending request with ID `id`. The entry stores the
     * expected response type. Throws an error if the Protocol Error is violated.
     */
    add(id: number, expectedResponseType: InboundResponseType | OutboundResponseType): void;
    /**
     * Resolves a pending request with matching ID `id` and expected response type
     * `type`. Throws an error if the Protocol Error is violated.
     */
    resolve(id: number, type: InboundResponseType | OutboundResponseType): void;
}
